@@ -1,8 +1,11 @@
 import datetime
-from typing import Any, Dict, List, Optional, Type
+import re
+from typing import Any, Dict, List, Optional, TypeVar
 
 from mindee.endpoints import Endpoint
-from mindee.inputs import InputDocument
+from mindee.fields.orientation import OrientationField
+from mindee.fields.position import PositionField
+from mindee.input.sources import InputSource
 
 TypeApiPrediction = Dict[str, Any]
 
@@ -14,14 +17,20 @@ def serialize_for_json(obj: Any) -> Any:
     Use as the `default` argument of the `json.dump` functions.
     """
     if isinstance(obj, datetime.date):
-        return obj.__str__()
+        return str(obj)
     return vars(obj)
 
 
+def clean_out_string(out_string: str) -> str:
+    """Clean up the string representation."""
+    regexp = re.compile(r" \n")
+    return regexp.sub("\n", out_string)
+
+
 class Document:
     type: str
     """Document type"""
-    checklist: dict = {}
+    checklist: dict
     """Validation checks for the document"""
     filepath: Optional[str] = None
     """Path of the input document"""
@@ -29,41 +38,60 @@ class Document:
     """Name of the input document"""
     file_extension: Optional[str] = None
     """File extension of the input document"""
+    # orientation is only present on page-level, not document-level
+    orientation: Optional[OrientationField] = None
+    """Page orientation"""
+    cropper: List[PositionField]
+    """Cropper results"""
 
     def __init__(
         self,
-        input_file: InputDocument,
+        input_source: InputSource,
         document_type: str,
         api_prediction: TypeApiPrediction,
         page_n: Optional[int] = None,
     ):
-        if input_file:
-            self.filepath = input_file.filepath
-            self.filename = input_file.filename
-            self.file_extension = input_file.file_mimetype
-
+        if input_source:
+            self.filepath = input_source.filepath
+            self.filename = input_source.filename
+            self.file_extension = input_source.file_mimetype
+        self.checklist = {}
         self.type = document_type
 
-        self._build_from_api_prediction(api_prediction, page_n=page_n)
-        self._checklist()
-        self._reconstruct()
+        if page_n is not None:
+            self._set_extras(api_prediction["extras"])
+            self.orientation = OrientationField(
+                api_prediction["orientation"], page_n=page_n
+            )
 
     @staticmethod
     def request(
         endpoints: List[Endpoint],
-        input_file: InputDocument,
+        input_source: InputSource,
         include_words: bool = False,
         close_file: bool = True,
+        cropper: bool = False,
     ):
         """
         Make request to prediction endpoint.
 
-        :param input_file: Input object
+        :param input_source: Input object
         :param endpoints: Endpoints config
         :param include_words: Include Mindee vision words in http_response
         :param close_file: Whether to `close()` the file after parsing it.
+        :param cropper: Including Mindee cropper results.
         """
-        return endpoints[0].predict_request(input_file, include_words, close_file)
+        return endpoints[0].predict_req_post(
+            input_source, include_words, close_file, cropper=cropper
+        )
+
+    def _set_extras(self, extras: TypeApiPrediction):
+        self.cropper = []
+        try:
+            for crop in extras["cropper"]["cropping"]:
+                self.cropper.append(PositionField(crop))
+        except KeyError:
+            pass
 
     def _build_from_api_prediction(
         self, api_prediction: TypeApiPrediction, page_n: Optional[int] = None
@@ -82,4 +110,4 @@ class Document:
         return all(self.checklist)
 
 
-TypeDocument = Type[Document]
+TypeDocument = TypeVar("TypeDocument", bound=Document)
